pub enum DecryptError {
InvalidTag,
WrongPlaintextLength,
PlaintextTooLong,
AadTooLong,
Unknown,
}Expand description
Error that can occur during decryption.
Variants
InvalidTag
The authentication tag is invalid; the ciphertext has been tampered with or the key/nonce/aad is incorrect.
WrongPlaintextLength
The plaintext buffer has the wrong length.
PlaintextTooLong
The plaintext is too long for this algorithm or implementation.
AadTooLong
The AAD is too long for this algorithm or implementation.
Unknown
An unknown error occurred during decryption.